@@ -17,20 +17,24 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling import Initializer
+from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
-from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithm import H2OSupervisedAlgorithm
+from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithmWithFoldColumn import H2OSupervisedAlgorithmWithFoldColumn
 from ai.h2o.sparkling.ml.params.H2OAutoMLParams import H2OAutoMLParams
-from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 from ai.h2o.sparkling.ml.algos.H2OAutoMLExtras import H2OAutoMLExtras
 
 
-class H2OAutoML(H2OAutoMLParams, H2OCommonParams, H2OSupervisedAlgorithm, H2OAutoMLExtras):
+class H2OAutoML(H2OAutoMLParams, H2OSupervisedAlgorithmWithFoldColumn, H2OAutoMLExtras):
 
     @keyword_only
     def __init__(self,
+                 ignoredCols=None,
+                 leaderboardDataFrame=None,
+                 blendingDataFrame=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -40,12 +44,10 @@ class H2OAutoML(H2OAutoMLParams, H2OCommonParams, H2OSupervisedAlgorithm, H2OAut
                  predictionCol="prediction",
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
-                 ignoredCols=None,
                  monotoneConstraints={},
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  projectName=None,
-                 nfolds=5,
+                 nfolds=-1,
                  balanceClasses=False,
                  classSamplingFactors=None,
                  maxAfterBalanceSize=5.0,
@@ -53,6 +55,11 @@ class H2OAutoML(H2OAutoMLParams, H2OCommonParams, H2OSupervisedAlgorithm, H2OAut
                  keepCrossValidationModels=False,
                  keepCrossValidationFoldAssignment=False,
                  exportCheckpointsDir=None,
+                 distribution="AUTO",
+                 tweediePower=1.5,
+                 quantileAlpha=0.5,
+                 huberAlpha=0.9,
+                 customDistributionFunc=None,
                  labelCol="label",
                  foldCol=None,
                  weightCol=None,
@@ -66,7 +73,7 @@ class H2OAutoML(H2OAutoMLParams, H2OCommonParams, H2OSupervisedAlgorithm, H2OAut
                  stoppingTolerance=-1.0,
                  excludeAlgos=None,
                  includeAlgos=["GLM", "DRF", "GBM", "DeepLearning", "StackedEnsemble", "XGBoost"],
-                 exploitationRatio=0.0):
+                 exploitationRatio=-1.0):
         Initializer.load_sparkling_jar()
         super(H2OAutoML, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OAutoML", self.uid)
