@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling import Initializer
+from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithmWithFoldColumn import H2OSupervisedAlgorithmWithFoldColumn
 from ai.h2o.sparkling.ml.models.H2OGAMMOJOModel import H2OGAMMOJOModel
