@@ -17,6 +17,7 @@
 
 from ai.h2o.sparkling.ml.params.H2OMOJOModelParams import H2OSupervisedMOJOModelParams
 from pyspark.ml.util import _jvm
+from py4j.java_gateway import JavaObject
 from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.models.H2OMOJOSettings import H2OMOJOSettings
 from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
@@ -32,6 +33,17 @@ class H2OGLMMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO):
         javaModel = _jvm().ai.h2o.sparkling.ml.models.H2OGLMMOJOModel.createFromMojo(pathToMojo, settings.toJavaObject())
         return H2OGLMMOJOModel(javaModel)
 
+
+    def getCrossValidationModels(self):
+        cvModels = self._java_obj.getCrossValidationModelsAsArray()
+        if cvModels is None:
+            return None
+        elif isinstance(cvModels, JavaObject):
+            return [H2OGLMMOJOModel(v) for v in cvModels]
+        else:
+            raise TypeError("Invalid type.")
+
+
     def getSeed(self):
         value = self._java_obj.getSeed()
         return value
@@ -222,6 +234,11 @@ class H2OGLMMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO):
         return value
 
 
+    def getGenerateScoringHistory(self):
+        value = self._java_obj.getGenerateScoringHistory()
+        return value
+
+
     def getNfolds(self):
         value = self._java_obj.getNfolds()
         return value
@@ -310,3 +327,6 @@ class H2OGLMMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO):
     def getAucType(self):
         value = self._java_obj.getAucType()
         return value
+
+    # Outputs
+
