@@ -17,6 +17,7 @@
 
 from ai.h2o.sparkling.ml.params.H2OMOJOModelParams import H2OTreeBasedSupervisedMOJOModelParams
 from pyspark.ml.util import _jvm
+from py4j.java_gateway import JavaObject
 from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.models.H2OMOJOSettings import H2OMOJOSettings
 from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
@@ -33,6 +34,17 @@ class H2OXGBoostMOJOModel(H2OTreeBasedSupervisedMOJOModelParams, HasMonotoneCons
         javaModel = _jvm().ai.h2o.sparkling.ml.models.H2OXGBoostMOJOModel.createFromMojo(pathToMojo, settings.toJavaObject())
         return H2OXGBoostMOJOModel(javaModel)
 
+
+    def getCrossValidationModels(self):
+        cvModels = self._java_obj.getCrossValidationModelsAsArray()
+        if cvModels is None:
+            return None
+        elif isinstance(cvModels, JavaObject):
+            return [H2OXGBoostMOJOModel(v) for v in cvModels]
+        else:
+            raise TypeError("Invalid type.")
+
+
     def getMaxDepth(self):
         value = self._java_obj.getMaxDepth()
         return value
@@ -331,3 +343,6 @@ class H2OXGBoostMOJOModel(H2OTreeBasedSupervisedMOJOModelParams, HasMonotoneCons
     def getAucType(self):
         value = self._java_obj.getAucType()
         return value
+
+    # Outputs
+
