@@ -22,10 +22,9 @@ from ai.h2o.sparkling.ml.params.HasIgnoredCols import HasIgnoredCols
 from ai.h2o.sparkling.ml.params.HasPlugValues import HasPlugValues
 from ai.h2o.sparkling.ml.params.HasBetaConstraints import HasBetaConstraints
 from ai.h2o.sparkling.ml.params.HasInteractionPairs import HasInteractionPairs
-from ai.h2o.sparkling.ml.params.DeprecatedDistribution import DeprecatedDistribution
 
 
-class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstraints, HasInteractionPairs, DeprecatedDistribution, Params):
+class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstraints, HasInteractionPairs, Params):
 
     ##
     # Param definitions
@@ -147,19 +146,19 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     objectiveEpsilon = Param(
         Params._dummy(),
         "objectiveEpsilon",
-        """Converge if  objective value changes less than this. Default indicates: If lambda_search is set to True the value of objective_epsilon is set to .0001. If the lambda_search is set to False and lambda is equal to zero, the value of objective_epsilon is set to .000001, for any other value of lambda the default value of objective_epsilon is set to .0001.""",
+        """Converge if  objective value changes less than this. Default (of -1.0) indicates: If lambda_search is set to True the value of objective_epsilon is set to .0001. If the lambda_search is set to False and lambda is equal to zero, the value of objective_epsilon is set to .000001, for any other value of lambda the default value of objective_epsilon is set to .0001.""",
         H2OTypeConverters.toFloat())
 
     gradientEpsilon = Param(
         Params._dummy(),
         "gradientEpsilon",
-        """Converge if  objective changes less (using L-infinity norm) than this, ONLY applies to L-BFGS solver. Default indicates: If lambda_search is set to False and lambda is equal to zero, the default value of gradient_epsilon is equal to .000001, otherwise the default value is .0001. If lambda_search is set to True, the conditional values above are 1E-8 and 1E-6 respectively.""",
+        """Converge if  objective changes less (using L-infinity norm) than this, ONLY applies to L-BFGS solver. Default (of -1.0) indicates: If lambda_search is set to False and lambda is equal to zero, the default value of gradient_epsilon is equal to .000001, otherwise the default value is .0001. If lambda_search is set to True, the conditional values above are 1E-8 and 1E-6 respectively.""",
         H2OTypeConverters.toFloat())
 
     objReg = Param(
         Params._dummy(),
         "objReg",
-        """Likelihood divider in objective value computation, default is 1/nobs""",
+        """Likelihood divider in objective value computation, default (of -1.0) will set it to 1/nobs""",
         H2OTypeConverters.toFloat())
 
     link = Param(
