@@ -8,18 +8,26 @@ class H2OCoxPHModel(ModelBase):
 
     def formula(self):
         """Survival formula."""
-        return self._model_json["output"]["formula"]
+        return self._model_json["output"]["formula"] 
+        
+    def concordance(self):
+        """Concordance"""
+        return self._model_json["output"]["concordance"]
 
     def coefficients_table(self):
         """Coefficients table."""
         return self._model_json["output"]["coefficients_table"]
 
-    def summary(self):
+    def show_summary(self):
         """Prints summary information about this model."""
         print("Call: ")
         print(self.formula())
         print(self.coefficients_table())
         output = self._model_json["output"]
         print("Likelihood ratio test=%f" % (output["loglik_test"]))
+        print("Concordance=%f" % (self.concordance()))
         print("n=%d, number of events=%d" % (output["n"], output["total_event"]))
 
+
+class H2OCoxPHMojoModel(ModelBase):
+    pass
